SystemOrganization addCategory: #'Tweak-Painter'!

CPlayer subclass: #CPainter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tweak-Painter'!

!CPainter commentStamp: 'tk 2/28/2005 14:01' prior: 0!
A Painter lets you make a drawing.  The picture becomes a live Tweak object when you click 'OK'.  Start a new painting by choosing Painter from the Tools menu in the menu bar.  Change an existing picture by bringing up its halo, and choosing 'repaint' from the menu on the red handle.[general]


### Allow Users to see the above explanation ###!

CPainter defineFields: '<?xml  version="1.0" ?>
<fields>
	<field toGet="board" toSet="board:" changeEvent="boardChanged">board</field>
	<field toGet="palette" toSet="palette:" changeEvent="paletteChanged">palette</field>
	<field toGet="buttons" toSet="buttons:" changeEvent="buttonsChanged">buttons</field>
	<field toGet="target" toSet="target:" changeEvent="targetChanged">target</field>
	<field toGet="newPlayer" toSet="newPlayer:" changeEvent="newPlayerChanged">newPlayer</field>
</fields>'!

!CPainter class methodsFor: 'class initialization' stamp: 'ar 1/22/2005 22:46'!
initialize
	"CPainter initialize"
	self registerOpenCommand.
! !

!CPainter class methodsFor: 'opening' stamp: 'bf 9/17/2004 17:55'!
openOnTarget: aPlayer

	^self new
		target: aPlayer;
		open;
		yourself! !

!CPainter class methodsFor: 'class initialization' stamp: 'ar 1/22/2005 22:45'!
registerOpenCommand
	"CPainter initialize"
	Smalltalk at: #CProjectBuilder ifPresent:[:pb|
		pb registerOpenCommand: { 'Painter' . { self . #open }. 'A Painting Tool' }.
	].! !

!CPainter methodsFor: 'accessing' stamp: 'bf 9/6/2004 16:39'!
board
	"Answer the board of the receiver"
	<bewareOf: #boardChanged>
	^self propertyValueAt: #board! !

!CPainter methodsFor: 'accessing' stamp: 'bf 9/6/2004 16:39'!
board: aValue
	"Modify the receiver's board"
	^self propertyValueAt: #board put: aValue with: #boardChanged! !

!CPainter methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:41'!
buttons
	"Answer the buttons of the receiver"
	<bewareOf: #buttonsChanged>
	^self propertyValueAt: #buttons! !

!CPainter methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:41'!
buttons: aValue
	"Modify the receiver's buttons"
	^self propertyValueAt: #buttons put: aValue with: #buttonsChanged! !

!CPainter methodsFor: 'initialize' stamp: 'bf 9/16/2004 17:41'!
initialize
	super initialize.

	self define: #board as: CPainterBoard new.
	self define: #palette as: CPainterPalette new.
	self define: #buttons as: CPainterButtons new.
! !

!CPainter methodsFor: 'accessing' stamp: 'ar 5/28/2005 20:14'!
newPlayer
	"Answer the newPlayer of the receiver"
	<bewareOf: #newPlayerChanged>
	^self propertyValueAt: #newPlayer! !

!CPainter methodsFor: 'accessing' stamp: 'ar 5/28/2005 20:14'!
newPlayer: aValue
	"Modify the receiver's newPlayer"
	^self propertyValueAt: #newPlayer put: aValue with: #newPlayerChanged! !

!CPainter methodsFor: 'events' stamp: 'bf 9/18/2004 00:46'!
onCancel
	<on: cancel>

	self close! !

!CPainter methodsFor: 'events' stamp: 'bf 9/17/2004 17:47'!
onClear
	<on: clear>
	board clear! !

!CPainter methodsFor: 'events' stamp: 'ar 5/28/2005 19:14'!
onLayoutChanged
	| box |
	<on: layoutChanged>
	box := self localBounds insetBy: borderWidth.
	board bounds: box.
	palette topRight: box topRight.
	buttons bottomLeft: box bottomLeft.
	buttons width: box width.
! !

!CPainter methodsFor: 'events' stamp: 'ar 6/25/2005 20:20'!
onOk
	<on: ok>
	newPlayer := board croppedPaintingPlayer.
	newPlayer
		ifNotNil: [
			target
				ifNil: [self container add: newPlayer]
				ifNotNil: [
					target graphicForm ifNotNil: [
						target extent := target extent * newPlayer extent 
							// target graphicForm extent].
					target graphicForm := newPlayer graphicForm]]
		ifNil: [
			target ifNotNil: [target graphicForm := nil]].

	self close! !

!CPainter methodsFor: 'events' stamp: 'bf 9/17/2004 17:47'!
onTargetChanged
	<on: targetChanged>

	(target graphic notNil and: [target graphic form notNil])
		ifTrue: [board croppedPainting := target graphic form copy]! !

!CPainter methodsFor: 'events' stamp: 'bf 9/18/2004 02:01'!
onUndo
	<on: undo>

	board undo! !

!CPainter methodsFor: 'accessing' stamp: 'bf 9/7/2004 17:09'!
palette
	"Answer the palette of the receiver"
	<bewareOf: #paletteChanged>
	^self propertyValueAt: #palette! !

!CPainter methodsFor: 'accessing' stamp: 'bf 9/7/2004 17:09'!
palette: aValue
	"Modify the receiver's palette"
	^self propertyValueAt: #palette put: aValue with: #paletteChanged! !

!CPainter methodsFor: 'initialize' stamp: 'ar 5/28/2005 21:50'!
setupCostume
	| |
	super setupCostume.

	extent := 400@400.

	fillStyle := #none.

	buttons hResizing := #spaceFill.

	self border style := #simple.
	self border width := 1.
	self border color := Color black.

	self add: board.
	self add: buttons.
	self add: palette.

	palette board: board.
	buttons painter: self.! !

!CPainter methodsFor: 'accessing' stamp: 'bf 9/17/2004 11:22'!
target
	"Answer the target of the receiver"
	<bewareOf: #targetChanged>
	^self propertyValueAt: #target! !

!CPainter methodsFor: 'accessing' stamp: 'bf 9/17/2004 11:22'!
target: aValue
	"Modify the receiver's target"
	^self propertyValueAt: #target put: aValue with: #targetChanged! !

CPlayer subclass: #CPainterBoard
	instanceVariableNames: ''
	classVariableNames: 'LastColor'
	poolDictionaries: ''
	category: 'Tweak-Painter'!

!CPainterBoard commentStamp: 'bf 9/2/2004 17:54' prior: 0!
Provides basic painting capabilities.

	tool		<Symbol>	any of the selectors in category "tools"
	toolSize	<Integer> 	diameter in pixels
	toolColor <Color>		color to paint with!

CPainterBoard defineFields: '<?xml  version="1.0" ?>
<fields>
	<field toGet="tool" toSet="tool:" changeEvent="toolChanged">tool</field>
	<field toGet="toolSize" toSet="toolSize:" changeEvent="toolSizeChanged">toolSize</field>
	<field toGet="toolColor" toSet="toolColor:" changeEvent="toolColorChanged">toolColor</field>
	<field virtual="true" serializable="false" toGet="painting" toSet="painting:">painting</field>
	<field virtual="true" serializable="false" toGet="croppedPainting" toSet="croppedPainting:">croppedPainting</field>
	<field toGet="undoList" toSet="undoList:" changeEvent="undoListChanged">undoList</field>
	<field toGet="brushRect" toSet="brushRect:" changeEvent="brushRectChanged">brushRect</field>
	<field toGet="cachedPen" toSet="cachedPen:" changeEvent="cachedPenChanged">cachedPen</field>
	<field toGet="cachedEraser" toSet="cachedEraser:" changeEvent="cachedEraserChanged">cachedEraser</field>
</fields>'!

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 5/10/2004 16:05'!
brushRect
	"Answer the brushRect of the receiver"
	<bewareOf: #brushRectChanged>
	^self propertyValueAt: #brushRect! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 5/10/2004 16:05'!
brushRect: aValue
	"Modify the receiver's brushRect"
	^self propertyValueAt: #brushRect put: aValue with: #brushRectChanged! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 5/10/2004 12:26'!
cachedEraser
	"Answer the cachedEraser of the receiver"
	<bewareOf: #cachedEraserChanged>
	^self propertyValueAt: #cachedEraser! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 5/10/2004 12:26'!
cachedEraser: aValue
	"Modify the receiver's cachedEraser"
	^self propertyValueAt: #cachedEraser put: aValue with: #cachedEraserChanged! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 5/10/2004 12:26'!
cachedPen
	"Answer the cachedPen of the receiver"
	<bewareOf: #cachedPenChanged>
	^self propertyValueAt: #cachedPen! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 5/10/2004 12:26'!
cachedPen: aValue
	"Modify the receiver's cachedPen"
	^self propertyValueAt: #cachedPen put: aValue with: #cachedPenChanged! !

!CPainterBoard methodsFor: 'private' stamp: 'bf 9/18/2004 01:10'!
clear
	painting fillColor: Color transparent.
	self invalidate.
	self signal: #paintingModified.
! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/18/2004 00:59'!
croppedPainting

	| rect |
	rect := painting innerPixelRectFor: 0 orNot: true.
	^ rect hasPositiveExtent
		ifTrue: [painting copy: rect]
		ifFalse: [nil]! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/18/2004 02:03'!
croppedPainting: aForm

	self clear.
	aForm displayOn: painting at: (painting boundingBox center - aForm boundingBox center).
	self signal: #paintingModified! !

!CPainterBoard methodsFor: 'accessing' stamp: 'ar 6/25/2005 23:28'!
croppedPaintingPlayer
	| rect target |
	rect := painting innerPixelRectFor: 0 orNot: true.
	rect hasPositiveExtent
		ifFalse: [^ nil].
	target := CPlayer new.
	target nose: 0@-1.
	target graphicForm: (painting copy: rect).
	target graphicFit: #stretch.
	target preciseCollisions: true.
	target bounds: rect.
	^ target! !

!CPainterBoard methodsFor: 'initialize' stamp: 'bf 11/24/2004 17:46'!
defaultForm
	^Form extent: 300@300 depth: 32! !

!CPainterBoard methodsFor: 'drawing' stamp: 'bf 9/2/2004 17:02'!
drawOn: aCanvas in: drawingBounds
	"If we are showing the pen or eraser, indicate its size"

	super drawOn: aCanvas in: drawingBounds.

	brushRect ifNotNil: [
		tool = #penTool
			ifTrue: [aCanvas frameOval: brushRect color: toolColor asNontranslucentColor]
			ifFalse: [aCanvas frameRectangle: brushRect color: Color black]]! !

!CPainterBoard methodsFor: 'tools' stamp: 'bf 9/18/2004 01:24'!
eraseTool
	"Invoked on mouseDown"

	(cachedEraser isNil or: [cachedEraser width ~= toolSize])
		ifTrue: [cachedEraser := ColorForm extent: toolSize@toolSize.
			cachedEraser fillWithColor: Color black.
			cachedEraser colors: (Array with: Color transparent with: Color transparent)].

	self paintWith: cachedEraser.
! !

!CPainterBoard methodsFor: 'tools' stamp: 'bf 9/18/2004 01:24'!
fillTool
	"Invoked on mouseDown"

	self signal: #toolColorUsed with: toolColor.

	self invalidate: ((painting
		floodFill: toolColor
		at: (self globalToLocal: hand position)) expandBy: 2).

	self signal: #paintingModified.
! !

!CPainterBoard methodsFor: 'testing' stamp: 'bf 9/2/2004 16:59'!
indicateBrush

	^ #(penTool eraseTool) includes: tool! !

!CPainterBoard methodsFor: 'initialize' stamp: 'bf 9/21/2004 15:55'!
initialize
	super initialize.

	self define: #tool as: #penTool.
	self define: #toolColor as: (LastColor ifNil: [Color red]).
	self define: #toolSize as: 8.

! !

!CPainterBoard methodsFor: 'events' stamp: 'bf 5/10/2004 16:31'!
onBrushRectChanged: newRect from: oldRect
	<on: brushRectChanged>

	newRect ifNotNil: [self invalidate: (newRect expandBy: 2)].
	oldRect ifNotNil: [self invalidate: (oldRect expandBy: 2)].
! !

!CPainterBoard methodsFor: 'events' stamp: 'bf 9/18/2004 01:22'!
onMouseDown
	<on: mouseDown>

	#(penTool fillTool eraseTool pipetteTool) yourself. "for finding senders"
	self perform: tool! !

!CPainterBoard methodsFor: 'events' stamp: 'bf 9/8/2004 14:56'!
onMouseLeave
	<on: mouseLeave>

	brushRect := nil! !

!CPainterBoard methodsFor: 'events' stamp: 'bf 9/2/2004 17:00'!
onMouseMove
	<on: mouseMove>

	self indicateBrush ifTrue: [
		| pos radius |
		pos := self globalToLocal: hand position.
		radius := toolSize // 2.
		brushRect := (pos - radius asPoint) extent: toolSize asPoint].! !

!CPainterBoard methodsFor: 'events' stamp: 'bf 9/18/2004 02:02'!
onPaintingModified
	<on: paintingModified>
	"No need to invalidate here - this happens only where the modification was done"

	self rememberUndo! !

!CPainterBoard methodsFor: 'events' stamp: 'bf 5/11/2004 10:22'!
onPlayerChanged
	<on: playerChanged>

	self onToolChanged.
! !

!CPainterBoard methodsFor: 'events' stamp: 'bf 9/2/2004 17:01'!
onToolChanged
	<on: toolChanged>

	self indicateBrush
		ifTrue: [self userDraw: true]
		ifFalse: [self userDraw: false.
			brushRect := nil]! !

!CPainterBoard methodsFor: 'events' stamp: 'bf 9/21/2004 15:56'!
onToolColorChanged
	<on: toolColorChanged>

	LastColor := toolColor! !

!CPainterBoard methodsFor: 'private' stamp: 'bf 9/18/2004 01:01'!
paintWith: brush
	| brushExtent brushCenter canvas lastPoint nextPoint |

	brushExtent := brush extent.
	brushCenter := brushExtent // 2.

	canvas := CTransformCanvas on: painting.

	nextPoint := lastPoint := (self globalToLocal: hand position) - brushCenter.
	canvas drawLineFrom: lastPoint to: nextPoint brush: brush.
	self invalidate: ((lastPoint extent: brushExtent) merge: (nextPoint extent: brushExtent)).

	self forEach: #mouseMove do: [:theEvent |
		theEvent withDroppedEventsDo: [:event |
			nextPoint := event arguments first position - brushCenter.
			canvas drawLineFrom: lastPoint to: nextPoint brush: brush.
			self invalidate: ((lastPoint extent: brushExtent) merge: (nextPoint extent: brushExtent)).
			lastPoint := nextPoint.
		].
	] until: #mouseUp.

	self signal: #paintingModified.
! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 11/24/2004 18:52'!
painting
	^myCostume ifNotNil: [graphicForm] "do not accidentally create costume"! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 11/22/2004 18:45'!
painting: aForm
	graphicForm := aForm.
	extent := aForm extent.! !

!CPainterBoard methodsFor: 'tools' stamp: 'bf 9/18/2004 01:24'!
penTool
	"Invoked on mouseDown"

	self signal: #toolColorUsed with: toolColor.

	(cachedPen isNil or: [cachedPen width ~= toolSize])
		ifTrue: [cachedPen := ColorForm dotOfSize: toolSize].
	cachedPen colors: (Array with: Color transparent with: toolColor).
	cachedPen offset: 0@0.

	self paintWith: cachedPen.
! !

!CPainterBoard methodsFor: 'tools' stamp: 'bf 9/18/2004 01:24'!
pipetteTool
	"Invoked on mouseDown"

	toolColor := world colorAt: hand position.

	self forEach: #mouseMove
		do: [toolColor := world colorAt: hand position]
		until: #mouseUp.! !

!CPainterBoard methodsFor: 'private' stamp: 'bf 9/18/2004 02:19'!
rememberUndo
	"We always keep a copy of the current painting as last undo step. This way, we take any performance hit here after drawing ends, rather than when it starts."
	| tmp |
	undoList ifNil: [undoList := OrderedCollection new: 5].
	undoList size < 4
		ifTrue: [tmp := painting deepCopy]
		ifFalse: [
			tmp := undoList removeFirst.
			tmp extent = painting extent
				ifTrue: [painting displayOn: tmp]
				ifFalse: [tmp := painting deepCopy]].
	undoList addLast: tmp! !

!CPainterBoard methodsFor: 'initialize' stamp: 'bf 11/24/2004 17:46'!
setupCostume
	super setupCostume.

	self graphicEnabled: true.
	graphicAnchorPoint := #topLeft.
	graphic fit := #rigid.

	painting ifNil: [painting := self defaultForm].

	fill color := Color white.
	fill alpha := 0.8.

	self onToolChanged.
! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/2/2004 16:35'!
tool
	"Answer the tool of the receiver"
	<bewareOf: #toolChanged>
	^self propertyValueAt: #tool! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/2/2004 16:35'!
tool: aValue
	"Modify the receiver's tool"
	^self propertyValueAt: #tool put: aValue with: #toolChanged! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/2/2004 16:55'!
toolColor
	"Answer the toolColor of the receiver"
	<bewareOf: #toolColorChanged>
	^self propertyValueAt: #toolColor! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/2/2004 16:55'!
toolColor: aValue
	"Modify the receiver's toolColor"
	^self propertyValueAt: #toolColor put: aValue with: #toolColorChanged! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/2/2004 16:54'!
toolSize
	"Answer the toolSize of the receiver"
	<bewareOf: #toolSizeChanged>
	^self propertyValueAt: #toolSize! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/2/2004 16:54'!
toolSize: aValue
	"Modify the receiver's toolSize"
	^self propertyValueAt: #toolSize put: aValue with: #toolSizeChanged! !

!CPainterBoard methodsFor: 'private' stamp: 'bf 9/18/2004 02:17'!
undo
	(undoList isNil or: [undoList size < 2])
		ifTrue: [^self].

	undoList addFirst: undoList removeLast.
	undoList last displayOn: painting.
	self invalidate.! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/18/2004 01:32'!
undoList
	"Answer the undoList of the receiver"
	<bewareOf: #undoListChanged>
	^self propertyValueAt: #undoList! !

!CPainterBoard methodsFor: 'accessing' stamp: 'bf 9/18/2004 01:32'!
undoList: aValue
	"Modify the receiver's undoList"
	^self propertyValueAt: #undoList put: aValue with: #undoListChanged! !

CPlayer subclass: #CPainterButtons
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Tweak-Painter'!

CPainterButtons defineFields: '<?xml  version="1.0" ?>
<fields>
	<field toGet="painter" toSet="painter:" changeEvent="painterChanged">painter</field>
	<field toGet="okButton" toSet="okButton:" changeEvent="okButtonChanged">okButton</field>
	<field toGet="cancelButton" toSet="cancelButton:" changeEvent="cancelButtonChanged">cancelButton</field>
	<field toGet="undoButton" toSet="undoButton:" changeEvent="undoButtonChanged">undoButton</field>
	<field toGet="clearButton" toSet="clearButton:" changeEvent="clearButtonChanged">clearButton</field>
</fields>'!

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:29'!
cancelButton
	"Answer the cancelButton of the receiver"
	<bewareOf: #cancelButtonChanged>
	^self propertyValueAt: #cancelButton! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:29'!
cancelButton: aValue
	"Modify the receiver's cancelButton"
	^self propertyValueAt: #cancelButton put: aValue with: #cancelButtonChanged! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:29'!
clearButton
	"Answer the clearButton of the receiver"
	<bewareOf: #clearButtonChanged>
	^self propertyValueAt: #clearButton! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:29'!
clearButton: aValue
	"Modify the receiver's clearButton"
	^self propertyValueAt: #clearButton put: aValue with: #clearButtonChanged! !

!CPainterButtons methodsFor: 'initialize' stamp: 'bf 9/16/2004 17:32'!
initialize
	super initialize.

	self define: #okButton as: CPushButton new.
	self define: #cancelButton as: CPushButton new.
	self define: #undoButton as: CPushButton new.
	self define: #clearButton as: CPushButton new.
! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:29'!
okButton
	"Answer the okButton of the receiver"
	<bewareOf: #okButtonChanged>
	^self propertyValueAt: #okButton! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:29'!
okButton: aValue
	"Modify the receiver's okButton"
	^self propertyValueAt: #okButton put: aValue with: #okButtonChanged! !

!CPainterButtons methodsFor: 'events' stamp: 'bf 9/17/2004 11:17'!
onCancelButtonFired
	<on: fire in: cancelButton>

	painter signal: #cancel! !

!CPainterButtons methodsFor: 'events' stamp: 'bf 9/17/2004 11:19'!
onClearButtonFired
	<on: fire in: clearButton>

	painter signal: #clear! !

!CPainterButtons methodsFor: 'events' stamp: 'bf 9/17/2004 11:18'!
onOkButtonFired
	<on: fire in: okButton>

	painter signal: #ok
! !

!CPainterButtons methodsFor: 'events' stamp: 'bf 9/17/2004 11:18'!
onUndoButtonFired
	<on: fire in: undoButton>
	
	painter signal: #undo! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/17/2004 10:22'!
painter
	"Answer the painter of the receiver"
	<bewareOf: #painterChanged>
	^self propertyValueAt: #painter! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/17/2004 10:22'!
painter: aValue
	"Modify the receiver's painter"
	^self propertyValueAt: #painter put: aValue with: #painterChanged! !

!CPainterButtons methodsFor: 'initialize' stamp: 'bf 9/18/2004 02:14'!
setupCostume
	super setupCostume.

	border style := #simple.
	border color := Color black.

	okButton label := 'OK'.
	okButton fill colors := {Color white. Color green}.
	okButton border color := Color black.
	okButton hResizing := #spaceFill.

	cancelButton label := 'Cancel'.
	cancelButton fill colors := {Color white. Color red}.
	cancelButton border color := Color black.
	cancelButton hResizing := #spaceFill.

	undoButton label := 'Undo'.
	undoButton fill colors := {Color white. Color orange}.
	undoButton border color := Color black.
	undoButton hResizing := #spaceFill.

	clearButton label := 'Clear'.
	clearButton fill colors := {Color white. Color yellow}.
	clearButton border color := Color black.
	clearButton hResizing := #spaceFill.

	layout := CTableLayout new.
	layout listDirection := #leftToRight.
	layout hResizing := #shrinkWrap.
	layout vResizing := #shrinkWrap.

	self add: undoButton.
	self add: clearButton.
	self add: cancelButton.
	self add: okButton.
! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:29'!
undoButton
	"Answer the undoButton of the receiver"
	<bewareOf: #undoButtonChanged>
	^self propertyValueAt: #undoButton! !

!CPainterButtons methodsFor: 'accessing' stamp: 'bf 9/16/2004 17:29'!
undoButton: aValue
	"Modify the receiver's undoButton"
	^self propertyValueAt: #undoButton put: aValue with: #undoButtonChanged! !

CSkin subclass: #CPainterPalette
	instanceVariableNames: ''
	classVariableNames: 'ImageCache RecentColors'
	poolDictionaries: ''
	category: 'Tweak-Painter'!

!CPainterPalette commentStamp: 'bf 9/16/2004 17:16' prior: 0!
A graphical palette for selecting the PainterBoard's current tool, size, and color.

Graphical Design by Anne Grngreiff. Created using impara's SkinMaker.!

CPainterPalette defineFields: '<?xml  version="1.0" ?>
<fields>
	<field toGet="board" toSet="board:" changeEvent="boardChanged" color="FF0000">board</field>
	<field toGet="toolsGroup" toSet="toolsGroup:" changeEvent="toolsGroupChanged" color="0000FF">toolsGroup</field>
	<field toGet="pipetteButton" toSet="pipetteButton:" changeEvent="pipetteButtonChanged" color="0000FF">pipetteButton</field>
	<field toGet="eraserButton" toSet="eraserButton:" changeEvent="eraserButtonChanged" color="0000FF">eraserButton</field>
	<field toGet="penButton" toSet="penButton:" changeEvent="penButtonChanged" color="0000FF">penButton</field>
	<field toGet="fillButton" toSet="fillButton:" changeEvent="fillButtonChanged" color="0000FF">fillButton</field>
	<field toGet="historyButton1" toSet="historyButton1:" changeEvent="historyButton1Changed">historyButton1</field>
	<field toGet="historyButton2" toSet="historyButton2:" changeEvent="historyButton2Changed">historyButton2</field>
	<field toGet="historyButton3" toSet="historyButton3:" changeEvent="historyButton3Changed">historyButton3</field>
	<field toGet="historyButton4" toSet="historyButton4:" changeEvent="historyButton4Changed">historyButton4</field>
	<field toGet="historyButton5" toSet="historyButton5:" changeEvent="historyButton5Changed">historyButton5</field>
	<field toGet="paletteButton" toSet="paletteButton:" changeEvent="paletteButtonChanged">paletteButton</field>
	<field toGet="noColorButton" toSet="noColorButton:" changeEvent="noColorButtonChanged">noColorButton</field>
	<field toGet="blackButton" toSet="blackButton:" changeEvent="blackButtonChanged">blackButton</field>
	<field toGet="whiteButton" toSet="whiteButton:" changeEvent="whiteButtonChanged">whiteButton</field>
	<field toGet="colorButton1" toSet="colorButton1:" changeEvent="colorButton1Changed">colorButton1</field>
	<field toGet="colorButton2" toSet="colorButton2:" changeEvent="colorButton2Changed">colorButton2</field>
	<field toGet="colorButton3" toSet="colorButton3:" changeEvent="colorButton3Changed">colorButton3</field>
	<field toGet="colorButton4" toSet="colorButton4:" changeEvent="colorButton4Changed">colorButton4</field>
	<field toGet="colorButton5" toSet="colorButton5:" changeEvent="colorButton5Changed">colorButton5</field>
	<field toGet="colorButton6" toSet="colorButton6:" changeEvent="colorButton6Changed">colorButton6</field>
	<field toGet="colorButton7" toSet="colorButton7:" changeEvent="colorButton7Changed">colorButton7</field>
	<field toGet="colorButton8" toSet="colorButton8:" changeEvent="colorButton8Changed">colorButton8</field>
	<field toGet="sizeGroup" toSet="sizeGroup:" changeEvent="sizeGroupChanged">sizeGroup</field>
	<field toGet="sizeButton1" toSet="sizeButton1:" changeEvent="sizeButton1Changed">sizeButton1</field>
	<field toGet="sizeButton2" toSet="sizeButton2:" changeEvent="sizeButton2Changed">sizeButton2</field>
	<field toGet="sizeButton3" toSet="sizeButton3:" changeEvent="sizeButton3Changed">sizeButton3</field>
	<field toGet="sizeButton4" toSet="sizeButton4:" changeEvent="sizeButton4Changed">sizeButton4</field>
	<field toGet="sizeButton5" toSet="sizeButton5:" changeEvent="sizeButton5Changed">sizeButton5</field>
	<field toGet="sizeButton6" toSet="sizeButton6:" changeEvent="sizeButton6Changed">sizeButton6</field>
	<field toGet="sizeButton7" toSet="sizeButton7:" changeEvent="sizeButton7Changed">sizeButton7</field>
	<field toGet="sizeButton8" toSet="sizeButton8:" changeEvent="sizeButton8Changed">sizeButton8</field>
	<field toGet="sizeButton9" toSet="sizeButton9:" changeEvent="sizeButton9Changed">sizeButton9</field>
	<field toGet="sizeButton10" toSet="sizeButton10:" changeEvent="sizeButton10Changed">sizeButton10</field>
	<field virtual="true" serializable="false" toGet="recentColors" toSet="recentColors:" changeEvent="recentColorsChanged">recentColors</field>
	<field toGet="eraseCursor" toSet="eraseCursor:" changeEvent="eraseCursorChanged">eraseCursor</field>
	<field toGet="penCursor" toSet="penCursor:" changeEvent="penCursorChanged">penCursor</field>
	<field toGet="pipetteCursor" toSet="pipetteCursor:" changeEvent="pipetteCursorChanged">pipetteCursor</field>
</fields>'!

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
blackButton
	"Answer the blackButton of the receiver"
	<bewareOf: #blackButtonChanged>
	^self propertyValueAt: #blackButton! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
blackButton: aValue
	"Modify the receiver's blackButton"
	^self propertyValueAt: #blackButton put: aValue with: #blackButtonChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/8/2004 12:32'!
board
	"Answer the board of the receiver"
	<bewareOf: #boardChanged>
	^self propertyValueAt: #board! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/8/2004 12:32'!
board: aValue
	"Modify the receiver's board"
	^self propertyValueAt: #board put: aValue with: #boardChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton1
	"Answer the colorButton1 of the receiver"
	<bewareOf: #colorButton1Changed>
	^self propertyValueAt: #colorButton1! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton1: aValue
	"Modify the receiver's colorButton1"
	^self propertyValueAt: #colorButton1 put: aValue with: #colorButton1Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton2
	"Answer the colorButton2 of the receiver"
	<bewareOf: #colorButton2Changed>
	^self propertyValueAt: #colorButton2! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton2: aValue
	"Modify the receiver's colorButton2"
	^self propertyValueAt: #colorButton2 put: aValue with: #colorButton2Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton3
	"Answer the colorButton3 of the receiver"
	<bewareOf: #colorButton3Changed>
	^self propertyValueAt: #colorButton3! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton3: aValue
	"Modify the receiver's colorButton3"
	^self propertyValueAt: #colorButton3 put: aValue with: #colorButton3Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton4
	"Answer the colorButton4 of the receiver"
	<bewareOf: #colorButton4Changed>
	^self propertyValueAt: #colorButton4! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton4: aValue
	"Modify the receiver's colorButton4"
	^self propertyValueAt: #colorButton4 put: aValue with: #colorButton4Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton5
	"Answer the colorButton5 of the receiver"
	<bewareOf: #colorButton5Changed>
	^self propertyValueAt: #colorButton5! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton5: aValue
	"Modify the receiver's colorButton5"
	^self propertyValueAt: #colorButton5 put: aValue with: #colorButton5Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton6
	"Answer the colorButton6 of the receiver"
	<bewareOf: #colorButton6Changed>
	^self propertyValueAt: #colorButton6! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton6: aValue
	"Modify the receiver's colorButton6"
	^self propertyValueAt: #colorButton6 put: aValue with: #colorButton6Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton7
	"Answer the colorButton7 of the receiver"
	<bewareOf: #colorButton7Changed>
	^self propertyValueAt: #colorButton7! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton7: aValue
	"Modify the receiver's colorButton7"
	^self propertyValueAt: #colorButton7 put: aValue with: #colorButton7Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton8
	"Answer the colorButton8 of the receiver"
	<bewareOf: #colorButton8Changed>
	^self propertyValueAt: #colorButton8! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
colorButton8: aValue
	"Modify the receiver's colorButton8"
	^self propertyValueAt: #colorButton8 put: aValue with: #colorButton8Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/16/2004 16:19'!
eraseCursor
	"Answer the eraseCursor of the receiver"
	<bewareOf: #eraseCursorChanged>
	^self propertyValueAt: #eraseCursor! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/16/2004 16:19'!
eraseCursor: aValue
	"Modify the receiver's eraseCursor"
	^self propertyValueAt: #eraseCursor put: aValue with: #eraseCursorChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
eraserButton
	"Answer the eraserButton of the receiver"
	<bewareOf: #eraserButtonChanged>
	^self propertyValueAt: #eraserButton! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
eraserButton: aValue
	"Modify the receiver's eraserButton"
	^self propertyValueAt: #eraserButton put: aValue with: #eraserButtonChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
fillButton
	"Answer the fillButton of the receiver"
	<bewareOf: #fillButtonChanged>
	^self propertyValueAt: #fillButton! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
fillButton: aValue
	"Modify the receiver's fillButton"
	^self propertyValueAt: #fillButton put: aValue with: #fillButtonChanged! !

!CPainterPalette methodsFor: 'cursors' stamp: 'bf 9/16/2004 16:58'!
fillCursor
	"no image yet"

	^Cursor crossHair! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton1
	"Answer the historyButton1 of the receiver"
	<bewareOf: #historyButton1Changed>
	^self propertyValueAt: #historyButton1! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton1: aValue
	"Modify the receiver's historyButton1"
	^self propertyValueAt: #historyButton1 put: aValue with: #historyButton1Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton2
	"Answer the historyButton2 of the receiver"
	<bewareOf: #historyButton2Changed>
	^self propertyValueAt: #historyButton2! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton2: aValue
	"Modify the receiver's historyButton2"
	^self propertyValueAt: #historyButton2 put: aValue with: #historyButton2Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton3
	"Answer the historyButton3 of the receiver"
	<bewareOf: #historyButton3Changed>
	^self propertyValueAt: #historyButton3! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton3: aValue
	"Modify the receiver's historyButton3"
	^self propertyValueAt: #historyButton3 put: aValue with: #historyButton3Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton4
	"Answer the historyButton4 of the receiver"
	<bewareOf: #historyButton4Changed>
	^self propertyValueAt: #historyButton4! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton4: aValue
	"Modify the receiver's historyButton4"
	^self propertyValueAt: #historyButton4 put: aValue with: #historyButton4Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton5
	"Answer the historyButton5 of the receiver"
	<bewareOf: #historyButton5Changed>
	^self propertyValueAt: #historyButton5! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
historyButton5: aValue
	"Modify the receiver's historyButton5"
	^self propertyValueAt: #historyButton5 put: aValue with: #historyButton5Changed! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 9/7/2004 16:54'!
initialize
	super initialize.

	self define: #toolsGroup as: CCollection new.
	self define: #sizeGroup as: CCollection new.
! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 9/16/2004 18:55'!
initializeButtons
	"automatically generated"

	self define: #pipetteButton as: self makeDefaultButton.
	self define: #eraserButton as: self makeDefaultButton.
	self define: #penButton as: self makeColorizedButton.
	self define: #fillButton as: self makeColorizedButton.
	self define: #colorButton1 as: self makeColorizedButton.
	self define: #colorButton2 as: self makeColorizedButton.
	self define: #colorButton3 as: self makeColorizedButton.
	self define: #colorButton4 as: self makeColorizedButton.
	self define: #colorButton5 as: self makeColorizedButton.
	self define: #colorButton6 as: self makeColorizedButton.
	self define: #colorButton7 as: self makeColorizedButton.
	self define: #colorButton8 as: self makeColorizedButton.
	self define: #paletteButton as: self makeDefaultButton.
	self define: #noColorButton as: self makeDefaultButton.
	self define: #blackButton as: self makeColorizedButton.
	self define: #whiteButton as: self makeColorizedButton.
	self define: #historyButton1 as: self makeColorizedButton.
	self define: #historyButton2 as: self makeColorizedButton.
	self define: #historyButton3 as: self makeColorizedButton.
	self define: #historyButton4 as: self makeColorizedButton.
	self define: #historyButton5 as: self makeColorizedButton.
	self define: #sizeButton1 as: self makeDefaultButton.
	self define: #sizeButton2 as: self makeDefaultButton.
	self define: #sizeButton3 as: self makeDefaultButton.
	self define: #sizeButton4 as: self makeDefaultButton.
	self define: #sizeButton5 as: self makeDefaultButton.
	self define: #sizeButton6 as: self makeDefaultButton.
	self define: #sizeButton7 as: self makeDefaultButton.
	self define: #sizeButton8 as: self makeDefaultButton.
	self define: #sizeButton9 as: self makeDefaultButton.
	self define: #sizeButton10 as: self makeDefaultButton.
! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 9/7/2004 11:25'!
makeColorizedButton
	| button |
	button := self makeDefaultButton.
	button colorize := true.
	^ button! !

!CPainterPalette methodsFor: 'cursors' stamp: 'bf 9/16/2004 18:58'!
makeEraseCursor
	"automatically generated"

	^ (Form extent: 37@34
		depth: 32
		bits: (Bitmap decompressFromByteArray: 'H4sIAAAAAAAAAEVWCzSV6Rr+7As2dVqtmmk5TReZo6lN7UKmUnIpUZaRbkrUUJ1KN9VUmEgH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' base64Decoded unzipped asByteArray)) offset: -8@-32! !

!CPainterPalette methodsFor: 'images' stamp: 'bf 9/16/2004 18:55'!
makeNormalImage
	"automatically generated"

	^ (Form extent: 128@297
		depth: 32
		bits: (Bitmap decompressFromByteArray: 'H4sIAAAAAAAAAI29BVSW6fY+/J7Jo47jcdRxDERAQLobpLtBRARUVFREbAwsEMFExe7uGnvs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' base64Decoded unzipped asByteArray))! !

!CPainterPalette methodsFor: 'images' stamp: 'bf 9/16/2004 18:55'!
makeOverImage
	"automatically generated"

	^ (Form extent: 128@297
		depth: 32
		bits: (Bitmap decompressFromByteArray: 'H4sIAAAAAAAAALX9dVzV2fY/jjMz9965MnfGcRzHUUdRkO7u7u4uFVEUA8VOQkRFBQxMQFAU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' base64Decoded unzipped asByteArray))! !

!CPainterPalette methodsFor: 'cursors' stamp: 'bf 9/16/2004 18:58'!
makePenCursor
	"automatically generated"

	^ (Form extent: 38@35
		depth: 32
		bits: (Bitmap decompressFromByteArray: 'H4sIAAAAAAAAAB1TeVDTZxr+/dtxOs5up9vO7tbt6KKVQyg3BAhISAgQAuSAQBKSUC4lJOFK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' base64Decoded unzipped asByteArray)) offset: -2@-2! !

!CPainterPalette methodsFor: 'cursors' stamp: 'bf 9/16/2004 18:58'!
makePipetteCursor
	"automatically generated"

	^ (Form extent: 31@38
		depth: 32
		bits: (Bitmap decompressFromByteArray: 'H4sIAAAAAAAAACWUC1SO2RrH33WOQVMm3ZDbR/VFiEiM6biUxuVUREfFTGkyyZdCaj6V2+Tr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' base64Decoded unzipped asByteArray)) offset: -2@-34! !

!CPainterPalette methodsFor: 'images' stamp: 'bf 9/16/2004 18:55'!
makePressedImage
	"automatically generated"

	^ (Form extent: 128@297
		depth: 32
		bits: (Bitmap decompressFromByteArray: 'H4sIAAAAAAAAAKW9B1RU2bYuXOe+e8d52qe7j+2xbSMqIiICIiCgIqIgWQVFxYw555wzKiAY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' base64Decoded unzipped asByteArray))! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
noColorButton
	"Answer the noColorButton of the receiver"
	<bewareOf: #noColorButtonChanged>
	^self propertyValueAt: #noColorButton! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
noColorButton: aValue
	"Modify the receiver's noColorButton"
	^self propertyValueAt: #noColorButton put: aValue with: #noColorButtonChanged! !

!CPainterPalette methodsFor: 'events' stamp: 'bf 9/8/2004 13:35'!
onBoardChanged
	<on: boardChanged>
	board ifNotNil: [
		self onToolChanged.
		self onToolColorChanged.
		self onToolSizeChanged.
	].
! !

!CPainterPalette methodsFor: 'colors' stamp: 'tak 5/21/2005 18:24'!
onPaletteButton
	| picker |
	<on: mouseDown in: paletteButton>

	picker := CColorPicker new.
	picker floating := true.
	picker player := board fieldNamed: #toolColor.
	picker openAt: (self localToGlobal: paletteButton center) - (picker extent // 2).
	picker pickColor.
! !

!CPainterPalette methodsFor: 'colors' stamp: 'bf 5/6/2004 23:33'!
onRecentColorsChanged
	<on: recentColorsChanged>

	#(historyButton1 historyButton2 historyButton3 historyButton4 historyButton5)
		with: recentColors
		do: [:buttonName :recentColor | 
			(self componentNamed: buttonName)	color: recentColor].
! !

!CPainterPalette methodsFor: 'events' stamp: 'bf 9/8/2004 13:35'!
onToolButtonFired: aButton
	"<on: fire in: {penButton. fillButton. moveButton. ... }>"

	board tool := aButton value.
! !

!CPainterPalette methodsFor: 'events' stamp: 'bf 9/16/2004 17:06'!
onToolChanged
	| toolButton |
	<on: toolChanged in: board>

	toolButton := toolsGroup detect: [:button | button value = board tool].
	toolButton select.
	board mouseCursor: (toolButton propertyValueAt: #toolCursor).! !

!CPainterPalette methodsFor: 'colors' stamp: 'bf 9/8/2004 13:36'!
onToolColorButtonFired: aButton
	"<on: fire in: {fillButton. blackButton. whiteButton. ... }>"

	board toolColor := aButton fill asColor.
	(#(penTool fillTool) includes: board tool)
		ifFalse: [board tool := #penTool]! !

!CPainterPalette methodsFor: 'colors' stamp: 'bf 9/8/2004 13:36'!
onToolColorChanged
	<on: toolColorChanged in: board>

	fillButton color := board toolColor.
	penButton color := board toolColor.
! !

!CPainterPalette methodsFor: 'colors' stamp: 'bf 9/8/2004 13:36'!
onToolColorUsed: aColor
	<on: toolColorUsed in: board>

	self rememberColor: aColor! !

!CPainterPalette methodsFor: 'events' stamp: 'bf 9/8/2004 13:37'!
onToolSizeButtonFired: aButton
	"<on: fire in: {sizeButton1. sizeButton2. sizeButton3. ... }>"

	board toolSize := aButton value.

	(#(eraseTool penTool) includes: board tool)
		ifFalse: [board tool := #penTool]! !

!CPainterPalette methodsFor: 'events' stamp: 'bf 9/8/2004 13:37'!
onToolSizeChanged
	<on: toolSizeChanged in: board>

	sizeGroup do: [:button |
		button value >= board toolSize
			ifTrue: [^button select]].

	sizeGroup last select! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
paletteButton
	"Answer the paletteButton of the receiver"
	<bewareOf: #paletteButtonChanged>
	^self propertyValueAt: #paletteButton! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
paletteButton: aValue
	"Modify the receiver's paletteButton"
	^self propertyValueAt: #paletteButton put: aValue with: #paletteButtonChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
penButton
	"Answer the penButton of the receiver"
	<bewareOf: #penButtonChanged>
	^self propertyValueAt: #penButton! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
penButton: aValue
	"Modify the receiver's penButton"
	^self propertyValueAt: #penButton put: aValue with: #penButtonChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/16/2004 16:19'!
penCursor
	"Answer the penCursor of the receiver"
	<bewareOf: #penCursorChanged>
	^self propertyValueAt: #penCursor! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/16/2004 16:19'!
penCursor: aValue
	"Modify the receiver's penCursor"
	^self propertyValueAt: #penCursor put: aValue with: #penCursorChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
pipetteButton
	"Answer the pipetteButton of the receiver"
	<bewareOf: #pipetteButtonChanged>
	^self propertyValueAt: #pipetteButton! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
pipetteButton: aValue
	"Modify the receiver's pipetteButton"
	^self propertyValueAt: #pipetteButton put: aValue with: #pipetteButtonChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/16/2004 16:19'!
pipetteCursor
	"Answer the pipetteCursor of the receiver"
	<bewareOf: #pipetteCursorChanged>
	^self propertyValueAt: #pipetteCursor! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/16/2004 16:19'!
pipetteCursor: aValue
	"Modify the receiver's pipetteCursor"
	^self propertyValueAt: #pipetteCursor put: aValue with: #pipetteCursorChanged! !

!CPainterPalette methodsFor: 'colors' stamp: 'bf 11/22/2004 16:18'!
recentColors
	<bewareOf: #recentColorsChanged>
	^ RecentColors ifNil: [RecentColors := (1 to: 5) collect: [:i | Color random]]! !

!CPainterPalette methodsFor: 'colors' stamp: 'bf 5/6/2004 12:30'!
recentColors: anArrayOfColors
	RecentColors = anArrayOfColors
		ifFalse: [
			self signal: #recentColorsChanged with: anArrayOfColors with: RecentColors.
			RecentColors := anArrayOfColors]! !

!CPainterPalette methodsFor: 'colors' stamp: 'ar 6/19/2005 10:48'!
rememberColor: aColor
	"Put aColor in our color history, but only if it is different from the primary colors"

false ifTrue:[
	"ar 6/19/2005: Disabled. It is very confusing if sometimes the colors 
	get added and sometimes they do not."
	"Do not remember primary colors"
	#(	noColorButton blackButton whiteButton
		colorButton1 colorButton2 colorButton3 colorButton4
		colorButton5 colorButton6 colorButton7 colorButton8
	)  do: [:buttonName | 
		(self componentNamed: buttonName)	fill asColor = aColor
			ifTrue: [^self]].
].			
	"If already first, do nothing"
	recentColors first = aColor
		ifTrue: [^self].

	"Move aColor to front"
	recentColors := ({aColor}, (self recentColors copyWithout: aColor)) first: 5.
! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupBlackButton
	"automatically generated"

	blackButton bounds: (49@232 corner: 73@256).
	blackButton shapeForm: (Form
	extent: 24@24
	depth: 1
	fromArray: #( 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040 4294966784 4294966784 4294966784 4294966272 4294966272 4294965248 4294965248 4294963200 4294959104 4294950912 4294950912 4294950912 4294836224 4294705152 4293918720 4292870144 4278190080 4026531840)
	offset: 0@0).
	self add: blackButton.! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 9/16/2004 18:55'!
setupButtons
	"automatically generated"

	self setupPipetteButton.
	self setupEraserButton.
	self setupPenButton.
	self setupFillButton.
	self setupColorButton1.
	self setupColorButton2.
	self setupColorButton3.
	self setupColorButton4.
	self setupColorButton5.
	self setupColorButton6.
	self setupColorButton7.
	self setupColorButton8.
	self setupPaletteButton.
	self setupNoColorButton.
	self setupBlackButton.
	self setupWhiteButton.
	self setupHistoryButton1.
	self setupHistoryButton2.
	self setupHistoryButton3.
	self setupHistoryButton4.
	self setupHistoryButton5.
	self setupSizeButton1.
	self setupSizeButton2.
	self setupSizeButton3.
	self setupSizeButton4.
	self setupSizeButton5.
	self setupSizeButton6.
	self setupSizeButton7.
	self setupSizeButton8.
	self setupSizeButton9.
	self setupSizeButton10.
! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupColorButton1
	"automatically generated"

	colorButton1 bounds: (49@186 corner: 83@215).
	colorButton1 shapeForm: (Form
	extent: 34@29
	depth: 1
	fromArray: #( 4292870144 0 4293918720 0 4294705152 0 4294950912 0 4294965248 0 4294966784 0 4294967168 0 4294967264 0 4294967280 0 4294967288 0 4294967292 0 4294967294 0 4294967295 0 4294967295 3221225472 4294967295 0 4294967294 0 4294967292 0 4294967288 0 4294967280 0 4294967264 0 4294967232 0 4294967168 0 4294967040 0 134217216 0 8387584 0 2095104 0 520192 0 253952 0 49152 0)
	offset: 0@0).
	self add: colorButton1.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupColorButton2
	"automatically generated"

	colorButton2 bounds: (66@200 corner: 96@232).
	colorButton2 shapeForm: (Form
	extent: 30@32
	depth: 1
	fromArray: #( 122880 258048 522240 1046528 2096128 4193792 8388096 16776960 33554176 67108608 134217600 268435328 536870848 1073741760 2147483584 4294967264 2147483632 1073741808 536870896 536870904 268435448 134217720 134217720 67108860 67108860 67108860 33554428 33554428 33554428 33554428 33554428 33554428)
	offset: 0@0).
	self add: colorButton2.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupColorButton3
	"automatically generated"

	colorButton3 bounds: (67@232 corner: 96@267).
	colorButton3 shapeForm: (Form
	extent: 29@35
	depth: 1
	fromArray: #( 67108856 67108856 67108856 67108856 67108856 67108856 134217720 134217720 134217720 268435448 268435448 536870904 536870904 1073741808 2147483632 4294967264 4294967264 4294967264 2147483616 1073741760 536870848 268435328 134217600 67108736 33553920 16776704 8387584 4192256 2093056 520192 253952 114688 114688 65536 65536)
	offset: 0@0).
	self add: colorButton3.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupColorButton4
	"automatically generated"

	colorButton4 bounds: (49@250 corner: 82@280).
	colorButton4 shapeForm: (Form
	extent: 33@30
	depth: 1
	fromArray: #( 122880 0 258048 0 1046528 0 2096128 0 16776704 0 268435200 0 4294967168 0 4294967232 0 4294967264 0 4294967280 0 4294967288 0 4294967294 0 4294967295 0 4294967295 2147483648 4294967295 2147483648 4294967295 2147483648 4294967295 2147483648 4294967295 2147483648 4294967295 0 4294967294 0 4294967292 0 4294967280 0 4294967232 0 4294967168 0 4294966784 0 4294966272 0 4294963200 0 4294934528 0 4293918720 0 4290772992 0)
	offset: 0@0).
	self add: colorButton4.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupColorButton5
	"automatically generated"

	colorButton5 bounds: (15@250 corner: 49@280).
	colorButton5 shapeForm: (Form
	extent: 34@30
	depth: 1
	fromArray: #( 61440 0 129024 0 261632 0 524032 0 1048544 0 2097144 0 4194303 3221225472 8388607 3221225472 16777215 3221225472 33554431 3221225472 67108863 3221225472 134217727 3221225472 268435455 3221225472 536870911 3221225472 4294967295 3221225472 2147483647 3221225472 1073741823 3221225472 1073741823 3221225472 536870911 3221225472 134217727 3221225472 67108863 3221225472 33554431 3221225472 8388607 3221225472 4194303 3221225472 2097151 3221225472 131071 3221225472 65535 3221225472 4095 3221225472 2047 3221225472 127 3221225472)
	offset: 0@0).
	self add: colorButton5.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupColorButton6
	"automatically generated"

	colorButton6 bounds: (3@232 corner: 33@264).
	colorButton6 shapeForm: (Form
	extent: 30@32
	depth: 1
	fromArray: #( 4294966784 4294966784 4294966784 4294966784 4294966784 4294966784 4294967040 4294967040 4294967040 4294967168 2147483520 2147483584 2147483584 2147483616 1073741808 1073741816 1073741816 536870908 536870896 268435424 134217664 134217600 67108608 67108352 33553408 16775168 8384512 8380416 8372224 4161536 4128768 1966080)
	offset: 0@0).
	self add: colorButton6.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupColorButton7
	"automatically generated"

	colorButton7 bounds: (3@199 corner: 33@232).
	colorButton7 shapeForm: (Form
	extent: 30@33
	depth: 1
	fromArray: #( 131072 393216 983040 4161536 4177920 8380416 16773120 16775168 33553408 33553920 67108608 134217600 134217664 268435424 268435440 536870904 536870908 1073741816 1073741808 1073741808 1073741792 1073741760 2147483584 2147483520 2147483520 2147483520 2147483392 4294967040 4294966784 4294966784 4294966784 4294966784 4294966784)
	offset: 0@0).
	self add: colorButton7.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupColorButton8
	"automatically generated"

	colorButton8 bounds: (18@186 corner: 49@215).
	colorButton8 shapeForm: (Form
	extent: 31@29
	depth: 1
	fromArray: #( 4094 16382 131070 1048574 4194302 16777214 33554430 67108862 268435454 536870910 1073741822 2147483646 4294967294 4294967294 4294967294 2147483646 1073741822 536870910 268435454 134217726 67108862 33554430 16777214 8388544 4193792 2095104 1040384 507904 196608)
	offset: 0@0).
	self add: colorButton8.! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 9/7/2004 16:51'!
setupColorButtons

	#(	noColorButton transparent
		blackButton	black
		whiteButton	white
		colorButton1 red
		colorButton2 orange
		colorButton3 yellow
		colorButton4	 green
		colorButton5 (green muchDarker)
		colorButton6 cyan
		colorButton7 blue
		colorButton8 magenta
		historyButton1 transparent
		historyButton2 transparent
		historyButton3 transparent
		historyButton4 transparent
		historyButton5 transparent
	) pairsDo: [:buttonName :colorSpec |
		| button |
		button := self componentNamed: buttonName.
		button color := Color colorFrom: colorSpec.
		self startScript: #onToolColorButtonFired:
			withArguments: {button}
			when: {button. #fire}].

	self onRecentColorsChanged.! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 9/7/2004 16:57'!
setupCostume

	super setupCostume.

	self setupColorButtons.
	self setupSizeButtons.
	self setupToolButtons.! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 9/16/2004 18:58'!
setupCursors
	"automatically generated"

	eraseCursor := self makeEraseCursor.
	penCursor := self makePenCursor.
	pipetteCursor := self makePipetteCursor.
! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupEraserButton
	"automatically generated"

	eraserButton bounds: (79@41 corner: 125@87).
	eraserButton shapeForm: (Form
	extent: 46@46
	depth: 1
	fromArray: #( 16383 4160749568 16383 4227858432 65535 4227858432 65535 4261412864 65535 4278190080 131071 4286578688 262143 4292870144 262143 4294443008 262143 4294443008 4194303 4294443008 4194303 4294443008 33554431 4294443008 33554431 4294443008 33554431 4294443008 134217727 4294443008 134217727 4294443008 4294967295 4294443008 4294967295 4294443008 4294967295 4294443008 4294967295 4294443008 4294967295 4294443008 4294967295 4294443008 4294967295 4294443008 4294967295 4294705152 4294967295 4294705152 4294967295 4294705152 4294967295 4294705152 4294967295 4294705152 4294967295 4294705152 4294967295 4294705152 4294967295 4294705152 4294967295 4294705152 4294967295 4294705152 4294967295 4294443008 4294967295 4293918720 4294967295 4290772992 4294967295 4278190080 4294967295 4261412864 4294967295 4160749568 4294967295 4026531840 4294967295 3758096384 536870911 3221225472 536870911 3221225472 16777088 0 8386560 0 4186112 0)
	offset: 0@0).
	self add: eraserButton.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupFillButton
	"automatically generated"

	fillButton bounds: (92@168 corner: 127@215).
	fillButton shapeForm: nil.
	self add: fillButton.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupHistoryButton1
	"automatically generated"

	historyButton1 bounds: (98@217 corner: 116@241).
	historyButton1 shapeForm: (Form
	extent: 18@24
	depth: 1
	fromArray: #( 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4292853760 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912 4294950912)
	offset: 0@0).
	self add: historyButton1.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupHistoryButton2
	"automatically generated"

	historyButton2 bounds: (97@241 corner: 120@266).
	historyButton2 shapeForm: (Form
	extent: 23@25
	depth: 1
	fromArray: #( 2147481600 2147483136 2147483136 4294966784 4294966784 4294966784 4294966784 4294966784 4294966784 4294966784 4294966784 4294966784 4294966784 4294966784 4294959104 4294959104 1073733632 536854528 67076096 67076096 33488896 33488896 33423360 33292288 8126464)
	offset: 0@0).
	self add: historyButton2.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupHistoryButton3
	"automatically generated"

	historyButton3 bounds: (82@257 corner: 104@282).
	historyButton3 shapeForm: (Form
	extent: 22@25
	depth: 1
	fromArray: #( 8355840 8372224 16775168 33552384 67107840 67107840 67107840 67107840 67107840 67107840 67107840 67107840 4294966272 4294966272 4294966272 4294965248 4294965248 4294965248 4294963200 4294963200 4294705152 4294443008 4293918720 4292870144 1065353216)
	offset: 0@0).
	self add: historyButton3.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupHistoryButton4
	"automatically generated"

	historyButton4 bounds: (110@255 corner: 128@276).
	historyButton4 shapeForm: (Form
	extent: 18@21
	depth: 1
	fromArray: #( 67092480 67092480 67092480 134201344 268419072 268419072 536854528 536854528 1073725440 2147467264 2147467264 4294950912 4294950912 4294950912 4294950912 4294950912 2147467264 2147467264 2147467264 2147467264 1073725440)
	offset: 0@0).
	self add: historyButton4.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupHistoryButton5
	"automatically generated"

	historyButton5 bounds: (93@277 corner: 125@291).
	historyButton5 shapeForm: (Form
	extent: 32@14
	depth: 1
	fromArray: #( 536870911 1073741823 2147483647 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295 4294967295)
	offset: 0@0).
	self add: historyButton5.! !

!CPainterPalette methodsFor: 'initialization' stamp: 'ar 1/22/2005 14:32'!
setupImages
	"Cache values in class variable"

	ImageCache ifNil: [ImageCache := Dictionary new].

	normalImage := ImageCache at: #normalImage ifAbsentPut: [self makeNormalImage].
	pressedImage := ImageCache at: #pressedImage ifAbsentPut: [self makePressedImage].
	overImage := ImageCache at: #overImage ifAbsentPut: [self makeOverImage].
! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupNoColorButton
	"automatically generated"

	noColorButton bounds: (26@232 corner: 49@256).
	noColorButton shapeForm: (Form
	extent: 23@24
	depth: 1
	fromArray: #( 4294966784 4294966784 4294966784 4294966784 4294966784 4294966784 2147483136 2147483136 2147483136 1073741312 1073741312 536870400 536870400 268434944 134217216 67108352 67108352 33553920 8388096 4193792 1048064 523776 65024 15872)
	offset: 0@0).
	self add: noColorButton.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupPaletteButton
	"automatically generated"

	paletteButton bounds: (26@209 corner: 49@232).
	paletteButton shapeForm: (Form
	extent: 23@23
	depth: 1
	fromArray: #( 15872 130560 523776 2096640 4193792 16776704 33553920 67108352 134217216 134217216 268434944 536870400 536870400 1073741312 1073741312 1073741312 2147483136 2147483136 4294966784 4294966784 4294966784 4294966784 4294966784)
	offset: 0@0).
	self add: paletteButton.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupPenButton
	"automatically generated"

	penButton bounds: (61@111 corner: 115@137).
	penButton shapeForm: (Form
	extent: 54@26
	depth: 1
	fromArray: #( 0 134152192 1023 4294901760 1023 4294950912 1023 4294950912 16383 4294959104 524287 4294963200 1048575 4294963200 4194303 4294965248 33554431 4294966272 33554431 4294966272 134217727 4294966272 536870911 4294966272 1073741823 4294966272 1073741823 4294966272 2147483647 4294966272 4294967295 4294966272 4294967295 4294966272 4294967295 4294966272 4294967295 4294966272 4294967295 4294965248 2147483647 4294965248 1073741823 4294965248 134217727 4294965248 33554431 4293918720 33554431 4293918720 33554431 4293918720)
	offset: 0@0).
	self add: penButton.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupPipetteButton
	"automatically generated"

	pipetteButton bounds: (57@17 corner: 100@66).
	pipetteButton shapeForm: (Form
	extent: 43@49
	depth: 1
	fromArray: #( 524287 3221225472 1048575 3758096384 2097151 4026531840 4194303 4227858432 8388607 4261412864 16777215 4278190080 16777215 4290772992 33554431 4290772992 33554431 4292870144 67108863 4292870144 67108863 4292870144 67108863 4292870144 67108863 4292870144 67108863 4292870144 67108863 4292870144 134217727 4292870144 268435455 4292870144 268435455 4292870144 268435455 4292870144 268435455 4292870144 268435455 4292870144 268435455 4292870144 268435455 4292870144 268435455 4292870144 268435455 4278190080 536870911 4278190080 1073741823 4227858432 2147483647 4227858432 2147483647 4227858432 2147483647 4160749568 4294967295 4026531840 4294967295 4026531840 4294967295 4026531840 4294967295 0 4294967295 0 4294967288 0 4294967288 0 4294967288 0 4294967264 0 4294967264 0 4294966272 0 4294966272 0 4294966272 0 1073740800 0 536869888 0 268434432 0 268434432 0 134216704 0 67107840 0)
	offset: 0@0).
	self add: pipetteButton.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton1
	"automatically generated"

	sizeButton1 bounds: (82@87 corner: 95@103).
	sizeButton1 shapeForm: nil.
	self add: sizeButton1.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton10
	"automatically generated"

	sizeButton10 bounds: (53@88 corner: 83@119).
	sizeButton10 shapeForm: (Form
	extent: 30@31
	depth: 1
	fromArray: #( 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967288 4294967292 4294967292 4294967292 4294967292 4294967292 4294967292 4294967292 4294967292 4294967292 4294967292 4294967292 4294967292 4294967232 4294965248 4294963200 4294950912)
	offset: 0@0).
	self add: sizeButton10.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton2
	"automatically generated"

	sizeButton2 bounds: (95@88 corner: 114@107).
	sizeButton2 shapeForm: (Form
	extent: 19@19
	depth: 1
	fromArray: #( 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294443008 4294443008 4294443008 4294443008 4294443008 4294443008 4294443008 4294443008)
	offset: 0@0).
	self add: sizeButton2.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton3
	"automatically generated"

	sizeButton3 bounds: (108@99 corner: 128@120).
	sizeButton3 shapeForm: (Form
	extent: 20@21
	depth: 1
	fromArray: #( 4294963200 4294963200 4294963200 4294963200 4294963200 4294963200 4294963200 4294963200 4294963200 4294963200 4294963200 4294963200 2147479552 2147479552 536866816 536866816 268431360 134213632 134213632 67104768 33550336)
	offset: 0@0).
	self add: sizeButton3.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton4
	"automatically generated"

	sizeButton4 bounds: (114@120 corner: 128@138).
	sizeButton4 shapeForm: (Form
	extent: 14@18
	depth: 1
	fromArray: #( 2147221504 2147221504 2147221504 2147221504 2147221504 2147221504 2147221504 2147221504 2147221504 2147221504 4294705152 4294705152 4294705152 4294705152 4294705152 786432 786432 786432)
	offset: 0@0).
	self add: sizeButton4.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton5
	"automatically generated"

	sizeButton5 bounds: (107@135 corner: 126@155).
	sizeButton5 shapeForm: (Form
	extent: 19@20
	depth: 1
	fromArray: #( 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 2147475456 2147475456 268427264 4186112 4186112 4186112 4186112 4186112)
	offset: 0@0).
	self add: sizeButton5.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton6
	"automatically generated"

	sizeButton6 bounds: (99@145 corner: 118@168).
	sizeButton6 shapeForm: (Form
	extent: 19@23
	depth: 1
	fromArray: #( 4278190080 4278190080 4286578688 4286578688 4293918720 4294950912 4294950912 4294950912 4294950912 4294950912 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104 4294959104)
	offset: 0@0).
	self add: sizeButton6.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton7
	"automatically generated"

	sizeButton7 bounds: (78@152 corner: 99@168).
	sizeButton7 shapeForm: nil.
	self add: sizeButton7.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton8
	"automatically generated"

	sizeButton8 bounds: (55@144 corner: 78@170).
	sizeButton8 shapeForm: nil.
	self add: sizeButton8.! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupSizeButton9
	"automatically generated"

	sizeButton9 bounds: (47@119 corner: 68@144).
	sizeButton9 shapeForm: (Form
	extent: 21@25
	depth: 1
	fromArray: #( 536868864 536868864 536862720 536838144 536805376 2147418112 2147352576 4294705152 4294705152 4294705152 4294705152 4294705152 4294836224 4294901760 4294959104 2147481600 2147481600 2147481600 536868864 536868864 536868864 536868864 536868864 536868864 536868864)
	offset: 0@0).
	self add: sizeButton9.! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 6/20/2005 11:35'!
setupSizeButtons
	#(	sizeButton1	1
		sizeButton2	2
		sizeButton3	3
		sizeButton4	5
		sizeButton5	7
		sizeButton6	9
		sizeButton7	11
		sizeButton8	13
		sizeButton9	19
		sizeButton10	31
	) pairsDo: [:buttonName :buttonValue | 
		| button |
		button := self componentNamed: buttonName.
		button value := buttonValue.
		button group := sizeGroup.
		sizeGroup add: button.
		self startScript: #onToolSizeButtonFired:
			withArguments: {button}
			when: {button. #fire}]! !

!CPainterPalette methodsFor: 'initialization' stamp: 'bf 9/16/2004 16:56'!
setupToolButtons

	#(	pipetteButton pipetteTool
		eraserButton eraseTool
		penButton penTool
		fillButton fillTool
	) pairsDo: [:buttonName :buttonValue |
		| button |
		button := self componentNamed: buttonName.
		button value := buttonValue.
		button group := toolsGroup.
		toolsGroup add: button.
		self startScript: #onToolButtonFired:
			withArguments: {button}
			when: {button. #fire}]. 

	#(	pipetteButton pipetteCursor
		eraserButton eraseCursor
		penButton penCursor
		fillButton fillCursor
	)  pairsDo: [:buttonName :cursorName |
		| button |
		button := self componentNamed: buttonName.
		button propertyValueAt: #toolCursor put: (self perform: cursorName)].
! !

!CPainterPalette methodsFor: 'buttons' stamp: 'bf 9/16/2004 18:55'!
setupWhiteButton
	"automatically generated"

	whiteButton bounds: (49@209 corner: 73@232).
	whiteButton shapeForm: (Form
	extent: 24@23
	depth: 1
	fromArray: #( 4160749568 4286578688 4292870144 4294443008 4294705152 4294901760 4294934528 4294950912 4294959104 4294963200 4294963200 4294965248 4294966272 4294966272 4294966784 4294966784 4294966784 4294967040 4294967040 4294967040 4294967040 4294967040 4294967040)
	offset: 0@0).
	self add: whiteButton.! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton1
	"Answer the sizeButton1 of the receiver"
	<bewareOf: #sizeButton1Changed>
	^self propertyValueAt: #sizeButton1! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/7/2004 17:02'!
sizeButton10
	"Answer the sizeButton10 of the receiver"
	<bewareOf: #sizeButton10Changed>
	^self propertyValueAt: #sizeButton10! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/7/2004 17:02'!
sizeButton10: aValue
	"Modify the receiver's sizeButton10"
	^self propertyValueAt: #sizeButton10 put: aValue with: #sizeButton10Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton1: aValue
	"Modify the receiver's sizeButton1"
	^self propertyValueAt: #sizeButton1 put: aValue with: #sizeButton1Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton2
	"Answer the sizeButton2 of the receiver"
	<bewareOf: #sizeButton2Changed>
	^self propertyValueAt: #sizeButton2! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton2: aValue
	"Modify the receiver's sizeButton2"
	^self propertyValueAt: #sizeButton2 put: aValue with: #sizeButton2Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton3
	"Answer the sizeButton3 of the receiver"
	<bewareOf: #sizeButton3Changed>
	^self propertyValueAt: #sizeButton3! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton3: aValue
	"Modify the receiver's sizeButton3"
	^self propertyValueAt: #sizeButton3 put: aValue with: #sizeButton3Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton4
	"Answer the sizeButton4 of the receiver"
	<bewareOf: #sizeButton4Changed>
	^self propertyValueAt: #sizeButton4! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton4: aValue
	"Modify the receiver's sizeButton4"
	^self propertyValueAt: #sizeButton4 put: aValue with: #sizeButton4Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton5
	"Answer the sizeButton5 of the receiver"
	<bewareOf: #sizeButton5Changed>
	^self propertyValueAt: #sizeButton5! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton5: aValue
	"Modify the receiver's sizeButton5"
	^self propertyValueAt: #sizeButton5 put: aValue with: #sizeButton5Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton6
	"Answer the sizeButton6 of the receiver"
	<bewareOf: #sizeButton6Changed>
	^self propertyValueAt: #sizeButton6! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton6: aValue
	"Modify the receiver's sizeButton6"
	^self propertyValueAt: #sizeButton6 put: aValue with: #sizeButton6Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton7
	"Answer the sizeButton7 of the receiver"
	<bewareOf: #sizeButton7Changed>
	^self propertyValueAt: #sizeButton7! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton7: aValue
	"Modify the receiver's sizeButton7"
	^self propertyValueAt: #sizeButton7 put: aValue with: #sizeButton7Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton8
	"Answer the sizeButton8 of the receiver"
	<bewareOf: #sizeButton8Changed>
	^self propertyValueAt: #sizeButton8! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton8: aValue
	"Modify the receiver's sizeButton8"
	^self propertyValueAt: #sizeButton8 put: aValue with: #sizeButton8Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton9
	"Answer the sizeButton9 of the receiver"
	<bewareOf: #sizeButton9Changed>
	^self propertyValueAt: #sizeButton9! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
sizeButton9: aValue
	"Modify the receiver's sizeButton9"
	^self propertyValueAt: #sizeButton9 put: aValue with: #sizeButton9Changed! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/7/2004 16:53'!
sizeGroup
	"Answer the sizeGroup of the receiver"
	<bewareOf: #sizeGroupChanged>
	^self propertyValueAt: #sizeGroup! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/7/2004 16:53'!
sizeGroup: aValue
	"Modify the receiver's sizeGroup"
	^self propertyValueAt: #sizeGroup put: aValue with: #sizeGroupChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/7/2004 16:55'!
toolsGroup
	"Answer the toolsGroup of the receiver"
	<bewareOf: #toolsGroupChanged>
	^self propertyValueAt: #toolsGroup! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/7/2004 16:55'!
toolsGroup: aValue
	"Modify the receiver's toolsGroup"
	^self propertyValueAt: #toolsGroup put: aValue with: #toolsGroupChanged! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
whiteButton
	"Answer the whiteButton of the receiver"
	<bewareOf: #whiteButtonChanged>
	^self propertyValueAt: #whiteButton! !

!CPainterPalette methodsFor: 'accessing' stamp: 'bf 9/6/2004 18:37'!
whiteButton: aValue
	"Modify the receiver's whiteButton"
	^self propertyValueAt: #whiteButton put: aValue with: #whiteButtonChanged! !
CPainter initialize!
